'''
Created on Aug 16, 2017

@author: sumanth-3058
'''

class ZCRMException(Exception):
    '''
    This is the custom exception class for handling for Client Library exceptions 
    '''
    message = 'Error occurred for {url}. Error Code: {code} Response error_content: {error_content}. Error Details::{error_details}'

    def __init__(self, url, status_code, err_message,exception_code='error',details=None,content=None):
        self.url = url
        self.status_code = status_code
        self.error_content = content
        self.error_message=err_message
        self.error_code=exception_code
        self.error_details=details
        Exception.__init__(self,status_code)

    def __str__(self):
        return self.message.format(url=self.url,code=self.status_code,error_content=self.error_content,error_details=self.error_details)

import logging
logger=logging.getLogger('Client_Library')    
class Logger(object):
    '''
    This class is to log the exceptions onto console
    '''
    @staticmethod
    def add_log(message,level=None,exception=None):
        logger.setLevel(logging.DEBUG)
        console_handler = logging.StreamHandler()
        # create formatter and add it to the handlers
        formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
        try:
            from .Utility import ZCRMConfigUtil
        except ImportError:
            from Utility import ZCRMConfigUtil
        log_path=ZCRMConfigUtil.config_prop_dict['applicationLogFilePath']
        if log_path is not None and log_path.strip()!="":
            import os
            log_path=os.path.join(log_path,'client_library.log')
            file_handler=logging.FileHandler(log_path)
            file_handler.setLevel(logging.DEBUG)
            file_handler.setFormatter(formatter)
            logger.addHandler(file_handler)
        
        console_handler.setLevel(logging.DEBUG)
        console_handler.setFormatter(formatter)
        # add the handlers to the logger
        logger.addHandler(console_handler)
        
        if(exception!=None):
            message+='; Exception Message::'+exception.__str__()
        if(level==logging.ERROR):
            logger.error(message)
        elif(level==logging.INFO or level==logging.DEBUG):
            logger.debug(message)
        elif(level==logging.WARNING):
            logger.warning(message)



'''
Created on Sep 14, 2017

@author: sumanth-3058
'''

try:
    from .Handler import OrganizationAPIHandler
except ImportError:
    from Handler import OrganizationAPIHandler

class ZCRMOrganization(object):
    '''
    classdocs
    '''

    def __init__(self, org_name,org_id):
        '''
        Constructor
        '''
        self.company_name=org_name
        self.org_id=org_id
        self.alias=None
        self.primary_zuid=None
        self.zgid=None
        self.primary_email=None
        self.website=None
        self.mobile=None
        self.phone=None
        self.employee_count=None
        self.description=None
        self.time_zone=None
        self.iso_code=None
        self.currency_locale=None
        self.currency_symbol=None
        self.street=None
        self.state=None
        self.city=None
        self.country=None
        self.zip_code=None
        self.country_code=None
        self.fax=None
        self.mc_status=None
        self.is_gapps_enabled=None
        self.paid_expiry=None
        self.trial_type=None
        self.trial_expiry=None
        self.is_paid_account=None
        self.paid_type=None
        
    @staticmethod
    def get_instance(org_name=None,org_id=None):
        return ZCRMOrganization(org_name,org_id)
    
    def get_user(self,user_id):
        return OrganizationAPIHandler.get_instance().get_user(user_id)
    def get_current_user(self):
        return OrganizationAPIHandler.get_instance().get_current_user()
    def get_all_users(self):
        return OrganizationAPIHandler.get_instance().get_all_users()
    def get_all_active_users(self):
        return OrganizationAPIHandler.get_instance().get_all_active_users()
    def get_all_deactive_users(self):
        return OrganizationAPIHandler.get_instance().get_all_deactive_users()
    def get_all_confirmed_users(self):
        return OrganizationAPIHandler.get_instance().get_all_confirmed_users()
    def get_all_not_confirmed_users(self):
        return OrganizationAPIHandler.get_instance().get_all_not_confirmed_users()
    def get_all_deleted_users(self):
        return OrganizationAPIHandler.get_instance().get_all_deleted_users()
    def get_all_active_confirmed_users(self):
        return OrganizationAPIHandler.get_instance().get_all_active_confirmed_users()
    def get_all_admin_users(self):
        return OrganizationAPIHandler.get_instance().get_all_admin_users()
    def get_all_active_confirmed_admin_users(self):
        return OrganizationAPIHandler.get_instance().get_all_active_confirmed_admin_users()
    def get_all_profiles(self):
        return OrganizationAPIHandler.get_instance().get_all_profiles()
    def get_profile(self,profile_id):
        return OrganizationAPIHandler.get_instance().get_profile(profile_id)
    def get_all_roles(self):
        return OrganizationAPIHandler.get_instance().get_all_roles()
    def get_role(self,role_id):
        return OrganizationAPIHandler.get_instance().get_role(role_id)
    def create_user(self,user_instance):
        return OrganizationAPIHandler.get_instance().create_user(user_instance)
    def update_user(self,user_instance):
        return OrganizationAPIHandler.get_instance().update_user(user_instance)
    def delete_user(self,user_id):
        return OrganizationAPIHandler.get_instance().delete_user(user_id)
    